"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var propsUpdater = function () {
    var updateMaps = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        updateMaps[_i] = arguments[_i];
    }
    return function (changes) {
        return updateMaps.forEach(function (updateMap) {
            /** updateMap can be any of:
             * A) { [prop]: (newValue) => void }
             * B) [ mutableObject, ...prop | { [prop]: [string objectKey] }]
             **/
            if (!Array.isArray(updateMap)) {
                // A
                return Object.entries(updateMap).forEach(function (_a) {
                    var prop = _a[0], updateFn = _a[1];
                    if (prop in changes) {
                        updateFn(changes[prop]);
                    }
                });
            }
            // B
            var mutableObject = updateMap[0];
            updateMap.slice(1).forEach(function (p) {
                if (typeof p === "object") {
                    Object.entries(p).forEach(function (_a) {
                        var prop = _a[0], objectKey = _a[1];
                        if (prop in changes) {
                            mutableObject[objectKey] = changes[prop];
                        }
                    });
                }
                else {
                    if (p in changes) {
                        mutableObject[p] = changes[p];
                    }
                }
            });
        });
    };
};
exports.default = propsUpdater;
